==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Block/ts/Block_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>Block</name>
    <message>
        <location filename="../Block.js" line="+67"/>
        <source>Block Tools</source>
        <translation>Blokgereedschap</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show block tools</source>
        <translation>Blokgereedschap tonen</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Block</source>
        <translation>&amp;Blok</translation>
    </message>
</context>
<context>
    <name>BlockDialog</name>
    <message>
        <location filename="../BlockDialog.js" line="+115"/>
        <source>Leading or trailing spaces.</source>
        <translation>Spaties voor of na.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is empty.</source>
        <translation>De bloknaam is leeg.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is invalid.</source>
        <translation>De bloknaam is onjuist.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Block &apos;%1&apos; already exists&lt;br&gt;and will be overwritten.</source>
        <translation>Block &quot;%1&quot; bestaat al&lt;br&gt;en zal worden overschreven.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block already exists.</source>
        <translation>Blok bestaat al.</translation>
    </message>
    <message>
        <location filename="../BlockDialog.ui" line="+17"/>
        <source>Block Data</source>
        <translation>Blok gegevens</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Block name:</source>
        <translation>Bloknaam:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>block 1</source>
        <translation>blok 1</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Block/ts/Block_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>Block</name>
    <message>
        <location filename="../Block.js" line="+67"/>
        <source>Block Tools</source>
        <translation>Blokgereedschap</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show block tools</source>
        <translation>Blokgereedschap tonen</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Block</source>
        <translation>&amp;Blok</translation>
    </message>
</context>
<context>
    <name>BlockDialog</name>
    <message>
        <location filename="../BlockDialog.js" line="+134"/>
        <source>Leading or trailing spaces.</source>
        <translation>Spaties voor of na.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is empty.</source>
        <translation>De bloknaam is leeg.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is invalid.</source>
        <translation>De bloknaam is onjuist.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Block &apos;%1&apos; already exists&lt;br&gt;and will be overwritten.</source>
        <translation>Block &quot;%1&quot; bestaat al&lt;br&gt;en zal worden overschreven.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block already exists.</source>
        <translation>Blok bestaat al.</translation>
    </message>
    <message>
        <location filename="../BlockDialog.ui" line="+17"/>
        <source>Block Data</source>
        <translation>Blok gegevens</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Block name:</source>
        <translation>Bloknaam:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>block 1</source>
        <translation>blok 1</translation>
    </message>
</context>
<context>
    <name>LayoutDialog</name>
    <message>
        <source>Layout</source>
        <translation type="vanished">Layout</translation>
    </message>
    <message>
        <source>Leading or trailing spaces.</source>
        <translation type="vanished">Spaties voor of na.</translation>
    </message>
    <message>
        <source>Layout name is empty.</source>
        <translation type="vanished">De layoutnaam is leeg.</translation>
    </message>
    <message>
        <source>Layout name is invalid.</source>
        <translation type="vanished">De layoutnaam is onjuist.</translation>
    </message>
    <message>
        <source>Layout &apos;%1&apos; already exists&lt;br&gt;and will be overwritten.</source>
        <translation type="vanished">Layout &quot;%1&quot; bestaat al&lt;br&gt;en zal worden overschreven.</translation>
    </message>
    <message>
        <source>Layout already exists.</source>
        <translation type="vanished">Layout bestaat al.</translation>
    </message>
    <message>
        <source>Layout Data</source>
        <translation type="vanished">Layout gegevens</translation>
    </message>
    <message>
        <source>Layout name:</source>
        <translation type="vanished">Layoutnaam:</translation>
    </message>
</context>
</TS>
